@@ -602,7 +602,7 @@ class AlertBox(sprite):
 
 class ScrollableBox(sprite):
 
-    def __init__(self, name, size, manager: Menu_Manager,speed=5, isactive=True, layer=0):
+    def __init__(self, name, size, manager: Menu_Manager,path:str=None,width_cursor=20,speed=5, isactive=True, layer=0):
         super(sprite, self).__init__()
         self.name = name
         self.layer = layer
@@ -611,14 +611,16 @@ class ScrollableBox(sprite):
         
         self.handles = []
         self.sprites:list[sprite] = []
-        self.speed = size[1]/120
+        self.speed = size[1]/120*speed
 
         self.rect = py.Rect(0,0,*size)
         self.initial_size = Vector2(self.rect.width,self.rect.height)
         self.offset = Vector2(0,0)
 
-        self.cursor = py.Surface((20,self.rect.height - self.get_max()))
-        self.cursor.fill((0,0,0))
+        if not path:
+            self.cursor = py.Surface((width_cursor,self.rect.height - self.get_max()))
+        else:
+            self.cursor = py.transform.scale(py.image.load(path),(width_cursor,self.rect.height - self.get_max()))
 
     @property
     def image(self):
@@ -676,6 +678,11 @@ class ScrollableBox(sprite):
 
     def set_scale(self, sca: Vector2, TopLeft=False): ...
 
+    def get_sprite(self,name):
+        for sprite in self.sprites:
+            if sprite.name == name:
+                return sprite
+
 class Menu(py.sprite.Group):
     """
     classe principale du Menu
